PCP Quality Assessment Protocol

# PCP Quality Assessment Protocol - QAP Anatomical Spatial Reports

After all processing has been completed, the designated output directory for the `qap_anatomical_spatial.py` workflow will contain a set of pdf files that contain the relevant reports for the set of scans undergoing quality assessment. The set of output pdfs includes one pdf file per input scan in the scan directory, e.g.: `qap_anatomical_spatial_sub-01.pdf`, which contains the T1 slice mosaic and QC metrics for that scan. There will also be a group report pdf in the main output directory, e.g.: `qap_anatomical_spatial_group.pdf`, that contains summary metrics for the entire set of scans.

## For the individual scan reports:

### The T1 Anatomical Slice Mosaic

This plot in the report for the scan being assessed, e.g.:

    Anatomical reoriented, subject sub-01 (session_1_anat_1)

is the rendering of the axial slices from the 3D stack created by the workflow. This image can be used to eyeball the quality of the overall signal in the anatomical scan, as it will be obvious if there were any problem areas where there was signal dropout resulting from a bad shim or other sources of signal distortion.

### The Spatial Metrics computed on the Anatomical Scan

The metrics displayed in the Summary Report, e.g.: `QC measures (subject sub-01_session_1)` were computed using the `qap_anatomical_spatial.py` workflow and have been displayed as violin plots. The stars in these plots denote where the score for the scans for this participant fall in the distribution of all scores for scans that were included as inputs to the anatomical-spatial workflow. If there are several scans per session for this individual, then the stars will be displayed adjacent to each other in the violin plot.

The metrics computed are as follows:

1. bg_size - Background mask size
2. fg_size - Foreground mask size
3. bg_mean - Mean intensity of the background mask
4. fg_mean - Mean intensity of the foreground mask
5. bg_std - Standard deviation of the background mask
6. fg_std - Standard deviation of the foreground mask
7. csf_size - Cerebrospinal fluid mask size
8. gm_size - Grey matter mask size
9. wm_size - White matter mask size
10. csf_mean - Mean intensity of the CSF mask
11. gm_mean - Mean intensity of the grey matter mask
12. wm_mean - Mean intensity of the white matter mask
13. csf_std - Standard deviation of the CSF mask
14. gm_std - Standard deviation of the grey matter mask
15. wm_std - Standard deviation of the white matter mask
16. cnr - Contrast to Noise Ratio
17. efc - Entropy Focus Criterion
18. fber - Foreground to Background Energy Ratio
19. fwhm - Full-width half maximum smoothness of the voxels averaged across the three coordinate axes, and also for each axis [x,y,x]
20. qi1 - Artifact Detection
21. snr - Signal to Noise Ratio

All metrics are described in more detail in the Taxonomy of QA Measures section of the QAP documentation. Please refer to the QAP website for descriptions of these metrics.

## For the group reports:

The violin plots included in the group report, e.g.: `qqap_anatomical_spatial_group.pdf`, are a graphical representation of the columnar values in the `qap_anatomical_spatial.csv` file that was created in the main output directory for the workflow. The scores for each metric described above were aggregated to create the distributions that were plotted in both the individual and group reports. Hence, the violin plots in the individual scan reports and the group reports are identical, except that the group reports do not contain any stars denoting individual scans. These group reports are intended to provide the user a means of visually inspecting the overall quality of the spatial data for that group of anatomical scans.